////////////////////////////////////////////////////////////
//
// SFML - Simple and Fast Multimedia Library
// Copyright (C) 2007-2025 Laurent Gomila (laurent@sfml-dev.org)
//
// This software is provided 'as-is', without any express or implied warranty.
// In no event will the authors be held liable for any damages arising from the use of this software.
//
// Permission is granted to anyone to use this software for any purpose,
// including commercial applications, and to alter it and redistribute it freely,
// subject to the following restrictions:
//
// 1. The origin of this software must not be misrepresented;
//    you must not claim that you wrote the original software.
//    If you use this software in a product, an acknowledgment
//    in the product documentation would be appreciated but is not required.
//
// 2. Altered source versions must be plainly marked as such,
//    and must not be misrepresented as being the original software.
//
// 3. This notice may not be removed or altered from any source distribution.
//
////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////
// Headers
////////////////////////////////////////////////////////////
#include <SFML/Window/InputImpl.hpp>
#include <SFML/Window/Keyboard.hpp>

#include <SFML/System/String.hpp>


namespace sf::Keyboard
{
////////////////////////////////////////////////////////////
bool isKeyPressed(Key key)
{
    return priv::InputImpl::isKeyPressed(key);
}

////////////////////////////////////////////////////////////
bool isKeyPressed(Scancode code)
{
    return priv::InputImpl::isKeyPressed(code);
}

////////////////////////////////////////////////////////////
Key localize(Scancode code)
{
    return priv::InputImpl::localize(code);
}

////////////////////////////////////////////////////////////
Scancode delocalize(Key key)
{
    return priv::InputImpl::delocalize(key);
}

////////////////////////////////////////////////////////////
String getDescription(Scancode code)
{
    return priv::InputImpl::getDescription(code);
}

////////////////////////////////////////////////////////////
void setVirtualKeyboardVisible(bool visible)
{
    priv::InputImpl::setVirtualKeyboardVisible(visible);
}

} // namespace sf::Keyboard
